<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>EffectSRConverterFactory</name>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="30"/>
        <source>SRC Plugin</source>
        <translation>Πρόσθετο SRC</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="50"/>
        <source>About Sample Rate Converter Plugin</source>
        <translation>Σχετικά με το πρόσθετο μετατροπής ρυθμού δειγματοληψίας</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="51"/>
        <source>Qmmp Sample Rate Converter Plugin</source>
        <translation>Qmmp πρόσθετο μετατροπής ρυθμού δειγματοληψίας</translation>
    </message>
    <message>
        <location filename="../effectsrconverterfactory.cpp" line="52"/>
        <source>Written by: Ilya Kotov &lt;forkotov02@ya.ru&gt;</source>
        <translation>Γράφτηκε από τον: Ilya Kotov &lt;forkotov02@ya.ru&gt;</translation>
    </message>
</context>
<context>
    <name>SRConverterSettingsDialog</name>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="14"/>
        <source>Sample Rate Converter Plugin Settings</source>
        <translation>Ρυθμίσεις πρόσθετου μετατροπής ρυθμού δειγματοληψίας</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="20"/>
        <source>Sample Rate (Hz):</source>
        <translation>Ρυθμός δειγματοληψίας (Hz):</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="40"/>
        <source>Interpolation Engine:</source>
        <translation>Μηχανή παρεμβολής:</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="48"/>
        <source>Best Sinc Interpolation</source>
        <translation>Καλύτερη παρεμβολή sinc</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="53"/>
        <source>Medium Sinc Interpolation</source>
        <translation>Μέση παρεμβολή sinc</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="58"/>
        <source>Fastest Sinc Interpolation</source>
        <translation>Τάχιστη παρεμβολή sinc</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="63"/>
        <source>ZOH Interpolation</source>
        <translation>Παρεμβολή ZOH</translation>
    </message>
    <message>
        <location filename="../srconvertersettingsdialog.ui" line="68"/>
        <source>Linear Interpolation</source>
        <translation>Γραμμική παρεμβολή</translation>
    </message>
</context>
</TS>
